import { 
  select, 
  csv, 
  scaleLinear, 
  max, 
  axisLeft,
  axisBottom,
  format,
  extent
} from 'd3';

import { dropdownMenu } from './dropdownMenu';

import { scatterPlot } from './scatterPlot';

let data;
let xColumn;
let yColumn;

const onXColumnClicked = column => {
	xColumn = column;
  render();
};

const onYColumnClicked = column => {
	yColumn = column;
  render();
};

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = () => {
  
  dropdownMenu(select('#x-menu'), {
  	options: data.columns,
    onOptionClicked: onXColumnClicked,
    selectedOption: xColumn
	});
  
  dropdownMenu(select('#y-menu'), {
  	options: data.columns,
    onOptionClicked: onYColumnClicked,
    selectedOption: yColumn
	});
  
  svg.call(scatterPlot, {
    titleLabel: 'Cars',
  	xValue: d => d[xColumn],
    xAxisLabel: xColumn,
  	yValue: d => d[yColumn],
  	yAxisLabel: yColumn,
  	circleRadius: 10,
    margin: {top: 40, right: 20, bottom: 130, left: 90},
    width,
    height,
    data
	});
}

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(loadedData => {
  data = loadedData;
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.cylinders = +d.cylinders;
      d.displacement = +d.displacement;
      d.horsepower = +d.horsepower;
      d.weight = +d.weight;
      d.acceleration = +d.acceleration;
      d.year = +d.year;
    });
  xColumn = data.columns[4];
  yColumn = data.columns[0];
  render();
});