import { 
  select, 
  csv, 
  scaleLinear, 
  max, 
  axisLeft,
  axisBottom,
  format,
  extent
} from 'd3';

export const scatterPlot = (selection, props) => {
  const {
    titleLabel,
    xValue,
    xAxisLabel,
    yValue,
    yAxisLabel,
    circleRadius,
    margin,
    width,
    height,
    data
  } = props;
  
  const innerWidth = width - margin.left - margin.right;
	const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const g = selection.selectAll('.container').data([null]);
  const gEnter = g.enter().append('g')
  	.attr('class', 'container');
  gEnter.merge(g)
    .attr('transform', `translate(${margin.left},${margin.top})`)
  
  const xAxisTickFormat = number =>
    format('.3s')(number)
      .replace('G', 'B');
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(10);
  
  const xAxisG = g.select('.x-axis')
  const xAxisGEnter = gEnter.append('g')
  	.attr('class', 'x-axis')
  
  xAxisG.merge(xAxisGEnter)
  	.call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  
  const xAxisLabelText = xAxisGEnter
  	.append('text')
  		.attr('class', 'axis-label')
      .attr('y', 50)
      .attr('text-anchor', 'middle')
      .attr('fill', 'black')
      .attr('font-size', '2em')
  	.merge(xAxisG.select('.axis-label'))
      .attr('x', innerWidth/2)
      .text(xAxisLabel);
  
  const yAxisTickFormat = number =>
    format('.2s')(number)
      .replace('G', 'B');
  
  const yAxis = axisLeft(yScale)
  	.tickFormat(yAxisTickFormat)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.select('.y-axis');
  const yAxisGEnter = gEnter.append('g')
  	.attr('class', 'y-axis')
  	
  yAxisG.merge(yAxisGEnter)
    	.call(yAxis);
  
  const yAxisLabelText = yAxisGEnter
  	.append('text')
      .attr('transform', 'rotate(90)')
  		.attr('class', 'axis-label')
      .attr('y', 70)
      .attr('text-anchor', 'middle')
      .attr('fill', 'black')
      .attr('font-size', '2em')
  	.merge(yAxisG.select('.axis-label'))
      .attr('x', innerHeight/2)
      .text(yAxisLabel);
  
  g.append('text')
  	.attr('y', -5)
  	.text(titleLabel);
  
  const circles = g.merge(gEnter)
  	.selectAll('circle').data(data);
  circles.enter().append('circle')
      .attr('cx', innerWidth / 2)
      .attr('cy', innerHeight / 2)
      .attr('r', 0)
  		.attr('class', 'points')
  	.merge(circles)
		.transition().duration(1000)
    .delay((d, i) => i * 5)
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
};